summaryrefslogtreecommitdiff
path: root/src/util/string.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/util/string.h')
-rw-r--r--src/util/string.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/util/string.h b/src/util/string.h
index 6c620587a..a3e0245aa 100644
--- a/src/util/string.h
+++ b/src/util/string.h
@@ -23,7 +23,7 @@
#include "util/rational.h"
-namespace CVC4 {
+namespace CVC5 {
/** The CVC4 string class
*
@@ -46,7 +46,7 @@ class String
static inline unsigned num_codes() { return 196608; }
/** constructors for String
*
* Internally, a CVC4::String is represented by a vector of unsigned
* integers (d_str) representing the code points of the characters.
*
* To build a string from a C++ string, we may process escape sequences
@@ -61,7 +61,7 @@ class String
* where d_0 ... d_4 are hexadecimal digits, to the appropriate character.
*
* If useEscSequences is false, then the characters of the constructed
* CVC4::String correspond one-to-one with the input string.
*/
String() = default;
explicit String(const std::string& s, bool useEscSequences = false)
@@ -112,7 +112,7 @@ class String
* If useEscSequences is false, the string's printable characters are
* printed as characters. Notice that for all std::string s having only
* printable characters, we have that
- * CVC4::String( s ).toString() = s.
+ * CVC5::String( s ).toString() = s.
*/
std::string toString(bool useEscSequences = false) const;
/* toWString
@@ -265,7 +265,8 @@ namespace strings {
struct StringHashFunction
{
- size_t operator()(const ::CVC4::String& s) const {
+ size_t operator()(const ::CVC5::String& s) const
+ {
return std::hash<std::string>()(s.toString());
}
}; /* struct StringHashFunction */
@@ -274,6 +275,6 @@ struct StringHashFunction
std::ostream& operator<<(std::ostream& os, const String& s);
-} // namespace CVC4
+} // namespace CVC5
#endif /* CVC4__UTIL__STRING_H */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -46,7 +46,7 @@ class String
/** constructors for String
*
- * Internally, a CVC4::String is represented by a vector of unsigned
+ * Internally, a CVC5::String is represented by a vector of unsigned
* integers (d_str) representing the code points of the characters.
*
@@ -61,7 +61,7 @@ class String
*
* If useEscSequences is false, then the characters of the constructed
- * CVC4::String correspond one-to-one with the input string.
+ * CVC5::String correspond one-to-one with the input string.
*/
String() = default;